document.addEventListener('DOMContentLoaded', () => {
  const form = document.getElementById('applicationForm');
  const modal = document.getElementById('conductModal');
  const showCodeBtn = document.getElementById('showCodeOfConduct');
  const closeBtn = document.getElementById('closeModal');
  
  // Show modal
  showCodeBtn.addEventListener('click', () => {
    modal.style.display = 'block';
  });
  
  // Close modal
  closeBtn.addEventListener('click', () => {
    modal.style.display = 'none';
  });
  
  // Close modal when clicking outside
  window.addEventListener('click', (e) => {
    if (e.target === modal) {
      modal.style.display = 'none';
    }
  });
  
  // Form submission
  form.addEventListener('submit', async (e) => {
    e.preventDefault();
    
    // Basic form validation
    const requiredFields = form.querySelectorAll('[required]');
    let isValid = true;
    
    requiredFields.forEach(field => {
      if (!field.value) {
        isValid = false;
        field.style.borderColor = 'var(--error-color)';
      } else {
        field.style.borderColor = '';
      }
    });
    
    if (!isValid) {
      alert('Please fill in all required fields');
      return;
    }
    
    // Simulate form submission
    const submitBtn = form.querySelector('.submit-btn');
    submitBtn.disabled = true;
    submitBtn.textContent = 'Submitting...';
    
    try {
      // Simulate API call
      await new Promise(resolve => setTimeout(resolve, 2000));
      
      alert('Application submitted successfully!');
      form.reset();
    } catch (error) {
      alert('An error occurred. Please try again.');
    } finally {
      submitBtn.disabled = false;
      submitBtn.textContent = 'Submit Application';
    }
  });
});
